<?php
/*
 * index.php
 *
 * LICENSE: This source file is subject to version 1.0 of the OpenFlyers license that is available through
 * the world-wide-web at the following URI: http://www.openflyers.com/license/semifreelicense1_0.txt.
 * If you did not receive a copy of the OpenFlyers License and are unable to obtain it through the web,
 * please send a note to contact@openflyers.com so we can mail you a copy immediately.
 *
 * @module      OAuth2
 * @package     OpenFlyers
 * @author      Guillaume Obin <gobin@enseirb-matmeca.fr>
 * @copyright   2008 OPENFLYERS S.A.R.L. <contact@openflyers.com>
 * @license     http://www.openflyers.com/license/semifreelicense1_0.txt  OpenFlyers License
 * @link        http://www.openflyers.com
 * @since       Mon, September 06, 2021
 *
 */

// Requiring ClientDemo.php to initialize properly demo class
require_once('./ClientDemo.php');

try {

    /** 
     * If you want assign a life time to your oauth2demo session in order to keep it alive even after closing your browser
     * Then you should use session_set_cookie_params PHP method
     * @link https://www.php.net/manual/en/function.session-set-cookie-params.php
     *
     * If you refrain from utilizing this method, then the cookies linked to your session will be destroyed upon closing your browser window.
     *
     * Alert!!!!
     * This method is not secure and may lead to security vulnerabilities on the OpenFlyers side,
     * Therefore, it is crucial to be cautious when utilizing it.
     *
     * @link https://openflyers.com/fr/doc/of4/API-OpenFlyers#Prolonger-la-durée-de-vie-de-la-session-du-client-de-démonstration
     *
     * @todo To activate session retention as described above, then you need to uncomment those two lines bellow
     */
    // Set the parameters for the session cookie in a PHP session in order to configure its lifetime in 30 days
    // $oauth2DemoSessionLifeTime = time() + (86400 * 30);
    // session_set_cookie_params($oauth2DemoSessionLifeTime);

    // Creating a user session, getting the structure from session and setting up root path directory
    session_start();

    // Instantiating a ClientDemo object for the OAuth 2.0 client demonstration
    $clientDemo     = new ClientDemo();

    // Retrieving form variables from POST and GET
    $authCode       = filter_input(INPUT_POST, 'authCode');
    $authResource   = filter_input(INPUT_POST, 'resourceUserId');
    $clientCred     = filter_input(INPUT_POST, 'clientCred');
    $getAuthCode    = filter_input(INPUT_GET, 'code');
    $reportResource = filter_input(INPUT_POST, 'reportCombo');

    /**
     * The form value sent is authCode meaning it is either a login or a logout
     * for the authorization code grant type
     */
    if ($authCode) {
        $clientDemo->authCodeLogin($authCode);
    }

    /**
     * The form value sent is resourceUserId meaning it is a resource retrieval
     * for the authorization code grant type
     */
    if ($authResource) {
        $clientDemo->getAuthResource();
    }

    /**
     * The form value sent is clientCred meaning it is either a login or a logout
     * for the client credentials grant type
     */
    if ($clientCred) {
        $clientDemo->clientCredLogin($clientCred);
    }

    /**
     * The form value sent is code meaning it is a request for an access token
     * for the authorization code grant type
     */
    if ($getAuthCode) {
        $clientDemo->getAuthToken();
    }

    /**
     * The form value sent is reportCombo meaning it is a report retrieval
     * for the client credentials grant type
     */
    if ($reportResource and is_null($clientCred) and is_null($authResource) and is_null($authCode)) {
        $clientDemo->getReportResource($reportResource);
    }

    // Displaying the form page
    $clientDemo->displayDemoPage();
} catch (Exception $error) {
    $clientDemo->addError($error);
    $clientDemo->displayDemoPage();
    die();
}
